Coverage report

# Coverage report: 54%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 3450 | 1571 | 0 | 54%
jbank/__init__.py | 1 | 0 | 0 | 100%
jbank/admin.py | 570 | 282 | 0 | 51%
jbank/apps.py | 5 | 0 | 0 | 100%
jbank/camt.py | 244 | 38 | 0 | 84%
jbank/csr_helpers.py | 42 | 10 | 0 | 76%
jbank/ecb.py | 18 | 2 | 0 | 89%
jbank/files.py | 15 | 2 | 0 | 87%
jbank/helpers.py | 161 | 48 | 0 | 70%
jbank/management/__init__.py | 0 | 0 | 0 | 100%
jbank/management/commands/__init__.py | 0 | 0 | 0 | 100%
jbank/management/commands/make_pain001.py | 63 | 63 | 0 | 0%
jbank/management/commands/make_x509.py | 29 | 29 | 0 | 0%
jbank/management/commands/parse_ecb_rates.py | 48 | 48 | 0 | 0%
jbank/management/commands/parse_svm.py | 62 | 14 | 0 | 77%
jbank/management/commands/parse_to.py | 61 | 14 | 0 | 77%
jbank/management/commands/parse_x509.py | 13 | 13 | 0 | 0%
jbank/management/commands/parse_xp.py | 62 | 62 | 0 | 0%
jbank/management/commands/parse_xt.py | 62 | 13 | 0 | 79%
jbank/management/commands/reparse_svm.py | 27 | 27 | 0 | 0%
jbank/management/commands/reparse_to.py | 27 | 27 | 0 | 0%
jbank/management/commands/test_app_req.py | 25 | 14 | 0 | 44%
jbank/management/commands/test_pain001.py | 32 | 17 | 0 | 47%
jbank/management/commands/test_payment.py | 21 | 10 | 0 | 52%
jbank/management/commands/test_svm.py | 11 | 3 | 0 | 73%
jbank/management/commands/test_to.py | 11 | 3 | 0 | 73%
jbank/management/commands/test_xp.py | 16 | 8 | 0 | 50%
jbank/management/commands/wsedi_download.py | 85 | 85 | 0 | 0%
jbank/management/commands/wsedi_exec.py | 28 | 28 | 0 | 0%
jbank/management/commands/wsedi_export.py | 36 | 36 | 0 | 0%
jbank/management/commands/wsedi_import.py | 49 | 49 | 0 | 0%
jbank/management/commands/wsedi_upload.py | 76 | 76 | 0 | 0%
jbank/management/commands/wspki_exec.py | 34 | 34 | 0 | 0%
jbank/management/commands/xmlsec1_examples.py | 19 | 19 | 0 | 0%
jbank/models.py | 530 | 112 | 0 | 79%
jbank/parsers.py | 307 | 40 | 0 | 87%
jbank/sepa.py | 174 | 19 | 0 | 89%
jbank/templates/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/jbank/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/jbank/referencepaymentbatch/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/admin/jbank/statement/__init__.py | 0 | 0 | 0 | 100%
jbank/templates/jbank/__init__.py | 0 | 0 | 0 | 100%
jbank/tests.py | 144 | 0 | 0 | 100%
jbank/views.py | 0 | 0 | 0 | 100%
jbank/wsedi.py | 120 | 120 | 0 | 0%
jbank/wspki.py | 189 | 189 | 0 | 0%
jbank/x509_helpers.py | 20 | 11 | 0 | 45%
manage.py | 13 | 6 | 0 | 54%

No items found using the specified filter.